@@ -55,6 +55,10 @@ HOME_FILE = "~/.home"
 """ The location of the file that may be used to "redirect"
 the home directory contents to a different directory """
 
+IMPORT_NAMES = ("$import", "$include", "$IMPORT", "$INCLUDE")
+""" The multiple possible definitions of the special configuration
+name that references a list of include files to be loaded """
+
 CASTS = {
     bool : lambda v: v if type(v) == bool else v == "1",
     list : lambda v: v if type(v) == list else v.split(";"),
@@ -161,6 +165,7 @@ def load_file(name = FILE_NAME, path = None, encoding = "utf-8"):
 
     file_path = os.path.abspath(file_path)
     file_path = os.path.normpath(file_path)
+    base_path = os.path.dirname(file_path)
 
     exists = os.path.exists(file_path)
     if not exists: return
@@ -176,11 +181,22 @@ def load_file(name = FILE_NAME, path = None, encoding = "utf-8"):
 
     data = data.decode(encoding)
     data_j = json.loads(data)
+
+    _load_includes(base_path, data_j, encoding = encoding)
+
     for key, value in data_j.items():
+        if not _is_valid(key): continue
         CONFIGS[key] = value
 
 def load_env():
-    for key, value in os.environ.items():
+    config = dict(os.environ)
+    homes = get_homes()
+
+    for home in homes:
+        _load_includes(home, config)
+
+    for key, value in legacy.iteritems(config):
+        if not _is_valid(key): continue
         CONFIGS[key] = value
         is_bytes = legacy.is_bytes(value)
         if not is_bytes: continue
@@ -233,6 +249,26 @@ def get_homes(
 
     return HOMES
 
+def _load_includes(base_path, config, encoding = "utf-8"):
+    includes = ()
+
+    for alias in IMPORT_NAMES:
+        includes = config.get(alias, includes)
+
+    if legacy.is_string(includes):
+        includes = includes.split(";")
+
+    for include in includes:
+        load_file(
+            name = include,
+            path = base_path,
+            encoding = encoding
+        )
+
+def _is_valid(key):
+    if key in IMPORT_NAMES: return False
+    return True
+
 def _is_devel():
     """
     Simple debug/development level detection mechanism to be
