@@ -649,6 +649,7 @@ def reference(target, name = None, dumpall = False):
         def __start__(self):
             if is_reference: self._target = self.__class__._target()
             else: self._target = target
+            util.verify(self._target)
             meta = getattr(self._target, name)
             self._type = meta.get("type", legacy.UNICODE)
 
@@ -658,7 +659,7 @@ def reference(target, name = None, dumpall = False):
 
         @classmethod
         def _target(cls):
-            if is_reference: return common.base().APP.models[target]
+            if is_reference: return common.base().APP.get_model(target)
             return target
 
         @classmethod
@@ -752,6 +753,8 @@ class References(AbstractType):
 
 def references(target, name = None, dumpall = False):
     name = name or "id"
+    target_t = type(target)
+    is_reference = target_t in legacy.STRINGS
     reference_c = reference(target, name = name, dumpall = dumpall)
 
     class _References(References):
@@ -762,6 +765,7 @@ def references(target, name = None, dumpall = False):
         may latter be used to cast the value """
 
         def __init__(self, ids):
+            self.__start__()
             if isinstance(ids, _References): self.build_i(ids)
             else: self.build(ids)
 
@@ -780,6 +784,11 @@ def references(target, name = None, dumpall = False):
         def __contains__(self, item):
             return self.contains(item)
 
+        def __start__(self):
+            if is_reference: self._target = self.__class__._target()
+            else: self._target = target
+            util.verify(self._target)
+
         @classmethod
         def _default(cls):
             return cls([])
@@ -834,6 +843,16 @@ def references(target, name = None, dumpall = False):
         def resolve(self, *args, **kwargs):
             return [object.resolve(*args, **kwargs) for object in self.objects]
 
+        def find(self, *args, **kwargs):
+            kwargs = dict(kwargs)
+            kwargs[name] = {"$in" : [self._target.cast(name, _id) for _id in self.ids]}
+            return self._target.find(*args, **kwargs)
+
+        def paginate(self, *args, **kwargs):
+            kwargs = dict(kwargs)
+            kwargs[name] = {"$in" : [self._target.cast(name, _id) for _id in self.ids]}
+            return self._target.paginate(*args, **kwargs)
+
         def is_empty(self):
             ids_l = len(self.ids)
             return ids_l == 0
